@@ -18,7 +18,7 @@ use CGI::FormBuilder::Util;
 use CGI::FormBuilder::Field;
 use CGI::FormBuilder::Messages;
 
-our $VERSION = '3.10';
+our $VERSION = '3.20';
 
 our $AUTOLOAD;
 
@@ -1150,8 +1150,12 @@ sub text {
                                              $inv,
                                              $self->invalid_tag).'</p>' if $inv;
 
-        return $self->{text} .'<p>'. sprintf($self->{messages}->form_required_text,
-                                             $self->required_tag).'</p>' if $req;
+        if ($req) {
+            my $form_required_text = $self->{messages}->form_required_text;
+            $form_required_text = sprintf($form_required_text, $self->required_tag)
+                if $form_required_text =~ /%/;
+            return $self->{text} ."<p>$form_required_text</p>";
+        }
     }
     return $self->{text};
 }
